==> ginkgocadx_2.5.1.0.orig.tar.gz: ginkgocadx-2.5.1.0/src/cadxcore/main/gui/callibration/procesarcalibrado.h <==
/*
 *  
 *  $Id: procesarcalibrado.h 3526 2011-03-16 19:56:19Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once
#include <api/iwizard.h>
#include <api/ivista.h>
#include <commands/inotificadorcalibrado.h>
#include "pasoscalibradobase.h"
#include <api/icontroladorprogreso.h>

#include <string>
#include <vector>

namespace GNC {
    namespace GCS {
        class IComando;
    }
}

namespace GNC {

	namespace GUI {

		struct TipoWizardCalibrado;

		class ProcesarCalibrado: public ProcesarCalibradoBase, public IPasoWizard, public GADAPI::INotificadorCalibrado,GNC::INotificadorProgreso
		{
			public:
				ProcesarCalibrado(wxWindow* pParent,IWizard* pWizard,TipoWizardCalibrado* pDatosPersistentes);
				~ProcesarCalibrado();

				void SetPuntosCalibrado(std::vector<GNC::GUI::TPuntoCalibrado>& puntos);
				virtual bool NotificarProgreso(float progresoNormalizado, const std::string& texto);


			protected:

				void OnRefrescoProgreso(wxCommandEvent& evt);

				TipoWizardCalibrado* m_pDatosPersistentes;
				bool m_Ok;
				GNC::GCS::IComando *m_pCmd;


			//region "Metodos heredados de IPasoWizard"
				virtual void Attach(wxSizer *sizer);

				virtual void Detach(wxSizer *sizer);

				virtual std::string GetTitle();

				virtual std::string GetSubTitle();

				virtual bool Siguiente();

				virtual bool Anterior();

				virtual bool Cancelar();

				virtual bool Validar();
			//endregion

				DECLARE_EVENT_TABLE()

		};
	}
}

==> ginkgocadx_2.12.0.4889.orig.tar.gz: ginkgocadx-2.12.0.4889/src/cadxcore/main/gui/callibration/procesarcalibrado.h <==
/*
 *  
 *  $Id: procesarcalibrado.h 4403 2011-11-14 10:59:24Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once
#include <api/iwizard.h>
#include <api/ivista.h>
#include <commands/inotificadorcalibrado.h>
#include "pasoscalibradobase.h"
#include <api/icontroladorprogreso.h>

#include <string>
#include <vector>

namespace GNC {
    namespace GCS {
        class IComando;
    }
}

namespace GNC {

	namespace GUI {

		struct TipoWizardCalibrado;

		class ProcesarCalibrado: public ProcesarCalibradoBase, public IPasoWizard, public GADAPI::INotificadorCalibrado,GNC::INotificadorProgreso
		{
			public:
				ProcesarCalibrado(wxWindow* pParent,IWizard* pWizard,TipoWizardCalibrado* pDatosPersistentes);
				~ProcesarCalibrado();

				void SetPuntosCalibrado(std::vector<GNC::GUI::TPuntoCalibrado>& puntos);
				virtual bool NotificarProgreso(float progresoNormalizado, const std::string& texto);


			protected:

				void OnRefrescoProgreso(wxCommandEvent& evt);

				TipoWizardCalibrado* m_pDatosPersistentes;
				bool m_Ok;
				GNC::GCS::IComando *m_pCmd;


			//region "Metodos heredados de IPasoWizard"
				virtual bool Attach();

				virtual bool Detach();

				virtual std::string GetTitle();

				virtual std::string GetSubTitle();

				virtual bool Siguiente();

				virtual bool Anterior();

				virtual bool Cancelar();

				virtual bool Validar();
			//endregion

				DECLARE_EVENT_TABLE()

		};
	}
}
